@@ -1,8 +1,8 @@
-from keras.layers import Conv3DTranspose
-from tensorflow import keras
 import logging
-from .utils import ensure_tf_type, ensure_numpy_type
 
+import keras
+
+from .utils import ensure_tf_type, ensure_numpy_type
 
 def convert_conv(node, params, layers, lambda_func, node_name, keras_name):
     """
@@ -56,7 +56,6 @@ def convert_conv(node, params, layers, lambda_func, node_name, keras_name):
             weights = [W, bias]
         else:
             weights = [W]
-
         conv = keras.layers.Conv3D(
             filters=out_channels,
             kernel_size=(dimension, height, width),
