@@ -1,4 +1,4 @@
-from tensorflow import keras
+import keras
 import tensorflow as tf
 import tensorflow_addons as tfa
 import logging
